<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['add'] = 'დამატება';
$labels['aclother'] = 'სხვა';
$labels['aclread'] = 'წაკითხვა';
$labels['acldelete'] = 'წაშლა';
$labels['shortaclr'] = 'წაკითხვა';
$labels['shortaclc'] = 'შექმნა';
$labels['shortaclk'] = 'შექმნა';
$labels['shortacld'] = 'წაშლა';
$labels['shortaclt'] = 'წაშლა';
$labels['shortaclother'] = 'სხვა';
$labels['shortaclread'] = 'წაკითხვა';
$labels['shortacldelete'] = 'წაშლა';
