<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/

$labels['basic'] = 'Tampilkan pemberitahuan pada peramban saat ada pesan baru';
$labels['desktop'] = 'Tampilkan pemberitahuan pada desktop saat ada pesan baru';
$labels['sound'] = 'Mainkan suara saat ada pesan baru';
$labels['test'] = 'Uji';
$labels['title'] = 'Email Baru!';
$labels['body'] = 'Anda telah menerima sebuah pesan baru.';
$labels['testbody'] = 'Ini adalah percobaan pemberitahuan.';
$labels['desktopdisabled'] = 'Pemberitahuan di desktop dimatikan pada peramban Anda.';
$labels['desktopunsupported'] = 'Peramban Anda tidak mendukung pemberitahuan pada desktop';
$labels['desktoptimeout'] = 'Tutup pemberitahuan pada desktop';
